<?php
/**
 * Copyright notice
 * (c) 2016 Oliver Thiele <mailYYYY@oliver-thiele.de>, Web Development Oliver Theiele
 * All rights reserved
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * This copyright notice MUST APPEAR in all copies of the script!
 */

use TYPO3\CMS\Backend\View\PageLayoutViewDrawItemHookInterface;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility;

/**
 * Class which hooks into tx_cms_layout and do additional tt_content_drawItem processing.
 *
 * @package TYPO3
 * @subpackage ot_bootstrap3
 * @author Oliver Thiele
 */
class OtBootstrap3TtContentDrawItem implements PageLayoutViewDrawItemHookInterface
{

    /**
     * Preprocesses the preview rendering of a content element.
     *
     * @param \TYPO3\CMS\Backend\View\PageLayoutView $parentObject :  Calling parent object
     * @param boolean $drawItem :      Whether to draw the item using the default functionalities
     * @param string $headerContent : Header content
     * @param string $itemContent :   Item content
     * @param array $row :           Record row of tt_content
     * @return void
     */
    public function preProcess(
        \TYPO3\CMS\Backend\View\PageLayoutView &$parentObject,
        &$drawItem,
        &$headerContent,
        &$itemContent,
        array &$row
    ) {
        $headerContent = $this->getBootstrapData($row) . $headerContent;

        // Show only type
        if ($row['CType'] === 'div') {
            # $drawItem = FALSE;
            $headerContent = $this->getBootstrapData($row);
            $itemContent = '';
        }
    }

    /**
     * Bootstrap data of a content element.
     *
     * @param array $row : Record row of tt_content
     * @return string
     */
    private function getBootstrapData($row)
    {
        $html = '<div class="table-responsive"><table class="table table-bordered table-condensed">';

        if ($row['CType'] === 'list') {
            $text = LocalizationUtility::translate('list_type.' . $row['list_type'],
                'ot_bootstrap3');
            if ($text === '') {
                $text = $row['list_type'];
            }
            $html .= '	<tr><th>Plugin</th><td><span title="' . $row['list_type'] . '">' . $text . '</span></td></tr>';
        } else {
            $text = LocalizationUtility::translate('CType.' . $row['CType'],
                'ot_bootstrap3');
            if ($text === '') {
                $text = $row['CType'];
            }
            $html .= '	<tr><th>CType</th><td><span title="' . $row['CType'] . '">' . $text . '</span></td></tr>';

            #todo flexform dividerType abfragen
//            if ($row['CType'] === 'ot_divider') {
//
//            }
        }

        if ($row['bootstrap_css'] != '') {
            $html .= '	<tr><th>CSS (outer &lt;div&gt;)</th><td> ' . $row['bootstrap_css'] . '</td></tr>';
        }
        if ($row['bootstrap_css_inner'] != '') {
            $html .= '<tr><th>CSS (inner &lt;div&gt;)</th><td> ' . $row['bootstrap_css_inner'] . '</td></tr>';
        }

        if ($row['bootstrap_col_xs'] . $row['bootstrap_col_sm'] . $row['bootstrap_col_md'] . $row['bootstrap_col_lg'] != '0000') {
            $html .= '<tr><th>Columns:</th><td>' .
                '<span class="label label-primary" style="padding:4px;display: inline-block;"><span style="font-size: 2em;" class="t3-icon fa t3-icon fa fa-mobile-phone"></span> ' . $row['bootstrap_col_xs'] . '</span> ' .
                '<span class="label label-primary" style="padding:4px;display: inline-block;"><span style="font-size: 2em;" class="t3-icon fa t3-icon fa fa-tablet"></span> ' . $row['bootstrap_col_sm'] . '</span> ' .
                '<span class="label label-primary" style="padding:4px;display: inline-block;"><span style="font-size: 2em;" class="t3-icon fa t3-icon fa fa-tablet fa-rotate-90"></span> ' . $row['bootstrap_col_md'] . '</span> ' .
                '<span class="label label-primary" style="padding:4px;display: inline-block;"><span style="font-size: 2em;" class="t3-icon fa t3-icon fa fa-desktop"></span>  ' . $row['bootstrap_col_lg'] . '</span> ' .
                '</td></tr>';
        }
        $html .= '</table></div>';

        return $html;
    }
}
