<?php
/**
 * Copyright notice
 * (c) 2016 Oliver Thiele <mailYYYY@oliver-thiele.de>, Web Development Oliver Theiele
 * All rights reserved
 *
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * This copyright notice MUST APPEAR in all copies of the script!
 */

namespace OliverThiele\OtBootstrap3\ViewHelpers;

use TYPO3\CMS\Fluid\Core\Rendering\RenderingContextInterface;
use TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper;
use TYPO3\CMS\Fluid\Core\ViewHelper\Facets\CompilableInterface;

/**
 * Class ContentElementWrapperViewHelper
 *
 * @package OliverThiele\OtBootstrap3\ViewHelpers
 */
class ContentElementWrapperViewHelper extends AbstractViewHelper implements CompilableInterface
{

    /**
     * @param string $value string to format
     * @return string the altered string.
     */
    public function render($value = null)
    {
        return static::renderStatic(
            array(
                'value' => $value
            ),
            $this->buildRenderChildrenClosure(),
            $this->renderingContext
        );
    }

    /**
     * @param array $arguments
     * @param \Closure $renderChildrenClosure
     * @param \TYPO3\CMS\Fluid\Core\Rendering\RenderingContextInterface $renderingContext
     * @return string
     */
    public static function renderStatic(
        array $arguments,
        \Closure $renderChildrenClosure,
        RenderingContextInterface $renderingContext
    ) {
        $cssColXs = '';
        $cssColSm = '';
        $cssColMd = '';
        $cssColLg = '';

        $value = $arguments['value'];
        if ($value === null) {
            $value = $renderChildrenClosure();
        }

        $all = $renderingContext->getTemplateVariableContainer()->getAll();
        $data = $all['data'];

        if ($data['bootstrap_col_xs']) {
            $cssColXs = ' col-xs-' . $data['bootstrap_col_xs'];
        }
        if ($data['bootstrap_col_sm']) {
            $cssColSm = ' col-sm-' . $data['bootstrap_col_sm'];
        }
        if ($data['bootstrap_col_md']) {
            $cssColMd = ' col-md-' . $data['bootstrap_col_md'];
        }
        if ($data['bootstrap_col_lg']) {
            $cssColLg = ' col-lg-' . $data['bootstrap_col_lg'];
        }

        $css = trim($cssColXs . $cssColSm . $cssColMd . $cssColLg);

        if ($css === '') {
            $css = 'col-xs-12';
        };

        /* animate */

        if ($data['animation_type'] != '0') {
            $cssAnimation = ' animate ';
            // todo DB

            if ($data['animation_delay'] != '0') {
                $animationDelay = ' data-animation-delay="' . $data['animation_delay'] . '"';
            } else {
                $animationDelay = '';
            }
            if ($data['animation_speed'] != '1000') {
                $animationSpeed = ' data-animation-speed="' . $data['animation_speed'] . '"';
            } else {
                $animationSpeed = '';
            }
            if ($data['animation_offset'] != '90%') {
                $animationOffset = ' data-animation-offset="' . $data['animation_offset'] . '"';
            } else {
                $animationOffset = '';
            }
            $dataAnimation = ' data-animation="' . $data['animation_type'] . '"' . $animationDelay . $animationSpeed . $animationOffset;
        } else {
            $cssAnimation = '';
            $dataAnimation = '';
        }

        $css .= ' ' . $data['bootstrap_css'];

        $cssClassesInnerDiv = trim($data['bootstrap_css_inner']);
        if ($cssClassesInnerDiv != '') {
            $innerDiv = [
                '<div class="' . $cssClassesInnerDiv . '">',
                '</div>'
            ];
        } else {
            $innerDiv = ['', ''];
        }

        $string = '<div id="ce' . $data['uid'] . '" class="fce-' . strtolower($data['CType']) . ' ' . $css . $cssAnimation . '"' . $dataAnimation . '>
        <a class="anchor" id="c' . $data['uid'] . '" ></a>' .
//        $string = '<a class="anchor" id="c' . $data['uid'] . '"></a><div id="ce' . $data['uid'] . '" class="fce-' . strtolower($data['CType']) . ' ' . $css . '" >' .
            $innerDiv[0] . $value . $innerDiv[1] .
            '</div>';
        return $string;
    }
}
