<?php
/**
 * Copyright notice
 * (c) 2016 Oliver Thiele <mailYYYY@oliver-thiele.de>, Web Development Oliver Theiele
 * All rights reserved
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * This copyright notice MUST APPEAR in all copies of the script!
 */

namespace OliverThiele\OtBootstrap3\ViewHelpers;

use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
use TYPO3\CMS\Fluid\Core\Rendering\RenderingContextInterface;
use TYPO3\CMS\Fluid\Core\ViewHelper\AbstractViewHelper;
use TYPO3\CMS\Fluid\Core\ViewHelper\Facets\CompilableInterface;

/**
 * Class CookieConsentViewHelper
 *
 * @package OliverThiele\OtBootstrap3\ViewHelpers
 */
class CookieConsentViewHelper extends AbstractViewHelper implements CompilableInterface
{

    /**
     * @param string $link
     * @param string $theme light-top | light-floating | light-bottom | dark-top | dark-floating | dark-bottom
     * @return string
     * @see http://silktide.com/cookieconsent
     */
    public function render($link, $theme = 'dark-top')
    {
        return static::renderStatic(
            [
                'link' => $link,
                'theme' => $theme
            ],
            $this->buildRenderChildrenClosure(),
            $this->renderingContext
        );
    }

    /**
     * @param array $arguments
     * @param \Closure $renderChildrenClosure
     * @param \TYPO3\CMS\Fluid\Core\Rendering\RenderingContextInterface $renderingContext
     * @return string
     */
    static public function renderStatic(
        array $arguments,
        \Closure $renderChildrenClosure,
        RenderingContextInterface $renderingContext
    ) {
        $link = $arguments['link'];
        $theme = $arguments['theme'];

        if ($link === null) {
            $link = $renderChildrenClosure();
        }

        $message = LocalizationUtility::translate('cookieconsent.message', 'ot_bootstrap3');
        $learnMore = LocalizationUtility::translate('cookieconsent.learnMore', 'ot_bootstrap3');
        $dismiss = LocalizationUtility::translate('cookieconsent.dismiss', 'ot_bootstrap3');

        $html = '<!-- Begin Cookie Consent plugin by Silktide - http://silktide.com/cookieconsent -->
<script type="text/javascript">
window.cookieconsent_options = {"message":"' . $message . '","dismiss":"' . $dismiss . '","learnMore":"' . $learnMore . '","link":"' . $link . '","theme":"' . $theme . '"};
</script>
<script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/cookieconsent2/1.0.9/cookieconsent.min.js"></script>
<!-- End Cookie Consent plugin -->';
        return $html;
    }
}
